==> datadog-api-client-2.2.0-sources.jar: com/datadog/api/client/v2/model/DashboardListDeleteItemsResponse.java <==
/*
 * Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 * This product includes software developed at Datadog (https://www.datadoghq.com/).
 * Copyright 2019-Present Datadog, Inc.
 */

package com.datadog.api.client.v2.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import java.util.ArrayList;
import java.util.List;
import java.util.Objects;

/** Response containing a list of deleted dashboards. */
@JsonPropertyOrder({DashboardListDeleteItemsResponse.JSON_PROPERTY_DELETED_DASHBOARDS_FROM_LIST})
@jakarta.annotation.Generated(
    value = "https://github.com/DataDog/datadog-api-client-java/blob/master/.generator")
public class DashboardListDeleteItemsResponse {
  @JsonIgnore public boolean unparsed = false;
  public static final String JSON_PROPERTY_DELETED_DASHBOARDS_FROM_LIST =
      "deleted_dashboards_from_list";
  private List<DashboardListItemResponse> deletedDashboardsFromList = null;

  public DashboardListDeleteItemsResponse deletedDashboardsFromList(
      List<DashboardListItemResponse> deletedDashboardsFromList) {
    this.deletedDashboardsFromList = deletedDashboardsFromList;
    for (DashboardListItemResponse item : deletedDashboardsFromList) {
      this.unparsed |= item.unparsed;
    }
    return this;
  }

  public DashboardListDeleteItemsResponse addDeletedDashboardsFromListItem(
      DashboardListItemResponse deletedDashboardsFromListItem) {
    if (this.deletedDashboardsFromList == null) {
      this.deletedDashboardsFromList = new ArrayList<>();
    }
    this.deletedDashboardsFromList.add(deletedDashboardsFromListItem);
    this.unparsed |= deletedDashboardsFromListItem.unparsed;
    return this;
  }

  /**
   * List of dashboards deleted from the dashboard list.
   *
   * @return deletedDashboardsFromList
   */
  @jakarta.annotation.Nullable
  @JsonProperty(JSON_PROPERTY_DELETED_DASHBOARDS_FROM_LIST)
  @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
  public List<DashboardListItemResponse> getDeletedDashboardsFromList() {
    return deletedDashboardsFromList;
  }

  public void setDeletedDashboardsFromList(
      List<DashboardListItemResponse> deletedDashboardsFromList) {
    this.deletedDashboardsFromList = deletedDashboardsFromList;
  }

  /** Return true if this DashboardListDeleteItemsResponse object is equal to o. */
  @Override
  public boolean equals(Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    DashboardListDeleteItemsResponse dashboardListDeleteItemsResponse =
        (DashboardListDeleteItemsResponse) o;
    return Objects.equals(
        this.deletedDashboardsFromList, dashboardListDeleteItemsResponse.deletedDashboardsFromList);
  }

  @Override
  public int hashCode() {
    return Objects.hash(deletedDashboardsFromList);
  }

  @Override
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("class DashboardListDeleteItemsResponse {\n");
    sb.append("    deletedDashboardsFromList: ")
        .append(toIndentedString(deletedDashboardsFromList))
        .append("\n");
    sb.append("}");
    return sb.toString();
  }

  /**
   * Convert the given object to string with each line indented by 4 spaces (except the first line).
   */
  private String toIndentedString(Object o) {
    if (o == null) {
      return "null";
    }
    return o.toString().replace("\n", "\n    ");
  }
}

==> datadog-api-client-2.28.0-sources.jar: com/datadog/api/client/v2/model/DashboardListDeleteItemsResponse.java <==
/*
 * Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 * This product includes software developed at Datadog (https://www.datadoghq.com/).
 * Copyright 2019-Present Datadog, Inc.
 */

package com.datadog.api.client.v2.model;

import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Objects;

/** Response containing a list of deleted dashboards. */
@JsonPropertyOrder({DashboardListDeleteItemsResponse.JSON_PROPERTY_DELETED_DASHBOARDS_FROM_LIST})
@jakarta.annotation.Generated(
    value = "https://github.com/DataDog/datadog-api-client-java/blob/master/.generator")
public class DashboardListDeleteItemsResponse {
  @JsonIgnore public boolean unparsed = false;
  public static final String JSON_PROPERTY_DELETED_DASHBOARDS_FROM_LIST =
      "deleted_dashboards_from_list";
  private List<DashboardListItemResponse> deletedDashboardsFromList = null;

  public DashboardListDeleteItemsResponse deletedDashboardsFromList(
      List<DashboardListItemResponse> deletedDashboardsFromList) {
    this.deletedDashboardsFromList = deletedDashboardsFromList;
    for (DashboardListItemResponse item : deletedDashboardsFromList) {
      this.unparsed |= item.unparsed;
    }
    return this;
  }

  public DashboardListDeleteItemsResponse addDeletedDashboardsFromListItem(
      DashboardListItemResponse deletedDashboardsFromListItem) {
    if (this.deletedDashboardsFromList == null) {
      this.deletedDashboardsFromList = new ArrayList<>();
    }
    this.deletedDashboardsFromList.add(deletedDashboardsFromListItem);
    this.unparsed |= deletedDashboardsFromListItem.unparsed;
    return this;
  }

  /**
   * List of dashboards deleted from the dashboard list.
   *
   * @return deletedDashboardsFromList
   */
  @jakarta.annotation.Nullable
  @JsonProperty(JSON_PROPERTY_DELETED_DASHBOARDS_FROM_LIST)
  @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
  public List<DashboardListItemResponse> getDeletedDashboardsFromList() {
    return deletedDashboardsFromList;
  }

  public void setDeletedDashboardsFromList(
      List<DashboardListItemResponse> deletedDashboardsFromList) {
    this.deletedDashboardsFromList = deletedDashboardsFromList;
  }

  /**
   * A container for additional, undeclared properties. This is a holder for any undeclared
   * properties as specified with the 'additionalProperties' keyword in the OAS document.
   */
  private Map<String, Object> additionalProperties;

  /**
   * Set the additional (undeclared) property with the specified name and value. If the property
   * does not already exist, create it otherwise replace it.
   *
   * @param key The arbitrary key to set
   * @param value The associated value
   * @return DashboardListDeleteItemsResponse
   */
  @JsonAnySetter
  public DashboardListDeleteItemsResponse putAdditionalProperty(String key, Object value) {
    if (this.additionalProperties == null) {
      this.additionalProperties = new HashMap<String, Object>();
    }
    this.additionalProperties.put(key, value);
    return this;
  }

  /**
   * Return the additional (undeclared) property.
   *
   * @return The additional properties
   */
  @JsonAnyGetter
  public Map<String, Object> getAdditionalProperties() {
    return additionalProperties;
  }

  /**
   * Return the additional (undeclared) property with the specified name.
   *
   * @param key The arbitrary key to get
   * @return The specific additional property for the given key
   */
  public Object getAdditionalProperty(String key) {
    if (this.additionalProperties == null) {
      return null;
    }
    return this.additionalProperties.get(key);
  }

  /** Return true if this DashboardListDeleteItemsResponse object is equal to o. */
  @Override
  public boolean equals(Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    DashboardListDeleteItemsResponse dashboardListDeleteItemsResponse =
        (DashboardListDeleteItemsResponse) o;
    return Objects.equals(
            this.deletedDashboardsFromList,
            dashboardListDeleteItemsResponse.deletedDashboardsFromList)
        && Objects.equals(
            this.additionalProperties, dashboardListDeleteItemsResponse.additionalProperties);
  }

  @Override
  public int hashCode() {
    return Objects.hash(deletedDashboardsFromList, additionalProperties);
  }

  @Override
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("class DashboardListDeleteItemsResponse {\n");
    sb.append("    deletedDashboardsFromList: ")
        .append(toIndentedString(deletedDashboardsFromList))
        .append("\n");
    sb.append("    additionalProperties: ")
        .append(toIndentedString(additionalProperties))
        .append("\n");
    sb.append('}');
    return sb.toString();
  }

  /**
   * Convert the given object to string with each line indented by 4 spaces (except the first line).
   */
  private String toIndentedString(Object o) {
    if (o == null) {
      return "null";
    }
    return o.toString().replace("\n", "\n    ");
  }
}
